@@ -72,6 +72,7 @@ def train_model(config: dict, fun_control: dict, timestamp: bool = True) -> floa
     """
     _L_in = fun_control["_L_in"]
     _L_out = fun_control["_L_out"]
+    _L_cond = fun_control["_L_cond"]
     _torchmetric = fun_control["_torchmetric"]
     if fun_control["enable_progress_bar"] is None:
         enable_progress_bar = False
@@ -86,7 +87,7 @@ def train_model(config: dict, fun_control: dict, timestamp: bool = True) -> floa
         # so that the model can be loaded from a checkpoint,
         # the config id is generated here without a timestamp.
         config_id = generate_config_id(config, timestamp=False) + "_TRAIN"
-    model = fun_control["core_model"](**config, _L_in=_L_in, _L_out=_L_out, _torchmetric=_torchmetric)
+    model = fun_control["core_model"](**config, _L_in=_L_in, _L_out=_L_out, _L_cond=_L_cond, _torchmetric=_torchmetric)
 
     dm = LightDataModule(
         dataset=fun_control["data_set"],
